<?php
/**
 * Class EmiteCheque
 *
 * PHP Version 5.3.14
 *
 * @category PHP
 * @package  Financeiro\Logic\ControleBancario\EmiteCheque
 * @author   leonardooliveira <leonardo.oliveira@teknisa.com>
 * @license  http://teknisa.com Teknisa
 * @link     http://localhost:9090/pebbian
 */
namespace Financeiro\Logic\ControleBancario\EmiteCheque;
use \Financeiro\Entities\Cheque;
use \Financeiro\Entities\Ittransfbanc;
use \Geral\Util\DateUtil;
use \Geral\Util\Ambiente;
use \Financeiro\Entities\Movdebbanc;
use \Setforms2\Shared\Registry;
use \Geral\Entities\Contcorr;
use Geral\Entities\Banco;
use \Setforms2\Shared\ORM\DateTime;

/**
 * Class EmiteCheque
 *
 * @category PHP
 * @package  Financeiro\Logic\ControleBancario\EmiteCheque
 * @author   leonardooliveira <leonardo.oliveira@teknisa.com>
 * @license  http://teknisa.com Teknisa
 * @link     http://localhost:9090/pebbian
 */
class EmiteCheque
{
    const ENV_VAR_EMISSAO_CHEQUE = 'DADOS_PBI00162_002';
    const POPUP_EMISSAO_CHEQUE = 'win_pbi00162_002';
    const CHEQUE_EMITIDO = '1';
    const DEBITO = 'D';
    const CREDITO = 'C';

    /**
     * Método utilizado
     *
     * @param int|string $nrorg      Nrorg
     * @param int|string $cdreducont Código conta corrente
     *
     * @return null|string
     */
    public function getModeloCheque($nrorg, $cdreducont)
    {

        /**
         * Método
         * @var $contcorr Contcorr
         */
        $contcorr = Contcorr::findOneByNrorgAndCdreducont($nrorg, $cdreducont);

        /**
         * Método
         * @var $dsarqcheque Banco
         */
        $dsarqcheque = Banco::findOneByCdbanco($contcorr->getcdbanco());
        $string = $dsarqcheque->getDsarqcheque();
        $tam = strlen($string);
        $tam_b = strrpos($string, '\\');
        $ext = -($tam - strrpos($string, '.'));
        if ($tam_b === false) {
            return null;
        } else {
                    return ($string_p = substr($string, ++$tam_b, $ext));
        }
    }

    /**
     * Método utilizado para atualizar o Cheque
     *
     * @param int|string $cdreducont   Conta corrente
     * @param int|string $nrcheque     Nr. Cheque
     * @param int|string $dtemischeq   Dt. Emissão
     * @param int|string $dtmovbancheq Dt. Movimento Banco
     * @param int|string $vrcheque     Valor do Cheque
     * @param int|string $dsnomcheq    Nome do Cheque
     *
     * @throws \Exception
     * @return null
     */
    public static function atualizaChequeEmitido($cdreducont, $nrcheque, $dtemischeq, $dtmovbancheq, $vrcheque, $dsnomcheq)
    {
        try {
            $nrorg = Ambiente::getNrorg();
            /**
             * Método
             * @var $cheque Cheque
             */
            $cheque = Cheque::findOneByNrorgAndCdreducontAndNrcheque($nrorg, $cdreducont, $nrcheque);
            $cheque->setIdstcheque(self::CHEQUE_EMITIDO);
            $cheque->setIdtpcanccheq(null);
            $cheque->setDtemischeq(self::_formataData($dtemischeq));
            $cheque->setDtmovbancheq(self::_formataData($dtmovbancheq));
            $cheque->setVrcheque($vrcheque);
            $cheque->setDsnomcheq($dsnomcheq);
            $cheque->setCdmoticanc(null);

            $cheque->persist();
            Registry::getEntityManager()->flush();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Método utilizado para atualizar o item da transferencia
     *
     * @param int|string $nrcheque   Nr. Cheque
     * @param int|string $cdempresa  Empresa
     * @param int|string $nrtranbanc Nr. Transferência
     * @param int|string $cdreducont Conta corrente
     *
     * @throws \Exception
     * @return null
     */
    public static function atualizaItemTransf($nrcheque, $cdempresa, $nrtranbanc, $cdreducont)
    {
        try {
            $nrorg = Ambiente::getNrorg();
            /**
             * Método
             * @var $itemCheque Ittransfbanc
             */
            $itemCheque = Ittransfbanc::findOneByNrorgAndCdreducontAndCdempresaAndNrtranbanc(
                $nrorg, $cdreducont, $cdempresa, $nrtranbanc
            );
            $itemCheque->setNrcheque($nrcheque);

            $itemCheque->persist();
            Registry::getEntityManager()->flush();

        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Método utilizado para atualizar o Lancamento
     *
     * @param int|string $nrcheque   Número cheque
     * @param int|string $nrtranbanc Número da transferencia
     * @param int|string $cdreducont Codigo conta corrente
     *
     * @return null
     * @throws \Exception
     */
    public static function atualizaItemLanc($nrcheque, $nrtranbanc, $cdreducont)
    {
        try {
            /**
             * Método
             * @var $movdebbanc Movdebbanc
             */
            $movdebbanc = Movdebbanc::findOneByCdreducontAndNrmovidebi($cdreducont, $nrtranbanc);
            $movdebbanc->setNrcheque($nrcheque);


            $movdebbanc->persist();
            Registry::getEntityManager()->flush();


        } catch (\Exception $e) {
            throw $e;
        }


    }

    /**
     * Método utilizado
     *
     * @param DateTime $data Data
     *
     * @return DateTime
     */
    private function _formataData($data)
    {
        $data = DateUtil::truncateString($data);
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);
        return $data;
    }

    /**
     * Abre a popup de emissão de cheque
     *
     * @param int|string $tipoemissao  Tipo emissao
     * @param int|string $cdempresa    Empresa
     * @param int|string $nrtranbanc   Número transferencia bancaria
     * @param int|string $cdreducont   Conta corrente
     * @param int|string $dtmovbancheq Data movimentacao
     * @param int|string $vrmovitbanc  Valor movimentacao
     * @param int|string $nrchequeaut  Número do Cheque Automático
     * @param int|string $nrchequeman  Número do Cheque Manual
     * @param int|string $dsnomcheq    Favorecido do cheque
     *
     * @return null
     */
    public static function abreEmissaoCheque($tipoemissao, $cdempresa, $nrtranbanc, $cdreducont,
                                             $dtmovbancheq, $vrmovitbanc, $nrchequeaut = NULL,
                                             $nrchequeman = null, $dsnomcheq = NULL, $opcao = NULL)
    {
        $dados = array(
            'TIPOEMISSAO' => $tipoemissao,
            'CDEMPRESA' => $cdempresa,
            'NRTRANBANC' => $nrtranbanc,
            'CDREDUCONT' => $cdreducont,
            'DTMOVBANCHEQ' => $dtmovbancheq,
            'VRMOVITBANC' => $vrmovitbanc,
            'NRCHEQUEAUT' => $nrchequeaut,
            'NRCHEQUEMAN' => $nrchequeman,
            'DSNOMCHEQ'   => $dsnomcheq,
            'OPCAO'       => $opcao
        );

        //envia os parâmetros para a próxima Window
        tk_set_env_var(self::ENV_VAR_EMISSAO_CHEQUE, $dados);

        tk_open_window(self::POPUP_EMISSAO_CHEQUE, true);
    }
}