/******************************************************************************
   FATURAMENTO COMISSARIA
   
   Procedure para Apurao de NFs por Delivery, com separao de produtos e 
   servios (Gera duas NFs novas a cada Delivery: Uma para os produtos e 
   outra para os servios (Produtos com incidencia de ISQN)). 
   
*******************************************************************************/ 

CREATE OR REPLACE PROCEDURE APURAC_DELIVERY_SEPPRODSERV(
   P_FILIAL    IN FILIAL.CDFILIAL%TYPE,
   P_FILIPROC  IN FILIAL.CDFILIAL%TYPE,
   P_CDCIA     IN COMPANHIA.CDCIA%TYPE,
   P_DTFECHAME IN DATE,
   P_DTINIAPUR IN DATE,
   P_DTFIMAPUR IN DATE,
   P_CDSERIE   IN SERIENF.CDSERIE%TYPE,
   P_IDTPIJURTRAN IN TRANSPORT.IDTPIJURTRAN%TYPE,
   P_NRINSJURTRAN IN TRANSPORT.NRINSJURTRAN%TYPE,
   P_NRAPURACFAT  IN NOTAFISCAL.NRAPURACFAT%TYPE)

AS

   V_NRSEQITPROD   NUMBER;

   V_CDCLIENTE     COMPANHIA.CDCLIENTE%TYPE;

   V_NRLANCTONF    VARCHAR(20);

   V_VRCOTDOLAR    TRAB_APURAC.VRCOTDOLARAP%TYPE;
   V_NRDELIVERY    TRAB_APURAC.NRDELIVERYAP%TYPE;
   V_CDFISCOPER    TRAB_APURAC.CDFISCOPERAP%TYPE;
   V_IDSERVICO     TRAB_APURAC.IDSERVICOAP%TYPE;
   V_IDPRODSERV    TRAB_APURAC.IDPRODSERVAP%TYPE;

   V_CDEMPRESA     FILIAL.CDEMPRESA%TYPE;
   V_CDINSCMUNI    FILIAL.CDINSCMUNI%TYPE;
   V_CDINSCESTA    FILIAL.CDINSCESTA%TYPE;

   V_IDTPIJURCLIE  CLIENTE.IDTPIJURCLIE%TYPE;
   V_NRINSJURCLIE  CLIENTE.NRINSJURCLIE%TYPE;

   V_NOVANOTA      VARCHAR(1);

   V_VRDESCDEL     DELIVERY.VRDESCDEL%TYPE;
   V_VRDESCSRV     DELIVERY.VRDESCSRV%TYPE;

   V_VRINDICE      MOVINDICE.VRINDICE%TYPE;
   V_VRUNITITEM    ITEMPRODUTO.VRUNITITEM%TYPE;

   V_IDCONMAXITEM  SERIENF.IDCONMAXITEM%TYPE;
   V_NRMAXITNF     SERIENF.NRMAXITNF%TYPE;
   V_NRMAXSERVNF   SERIENF.NRMAXSERVNF%TYPE;

   V_NRCOUNTPR     TRAB_APURAC.NRORDEMIS%TYPE;
   V_NRCOUNTSV     TRAB_APURAC.NRORDEMIS%TYPE;

   V_VRTAXAAERO    ITEMPRODUTO.VRUNITITEM%TYPE;
   V_VRTAXAAEME    ITEMPRODUTO.VRUNITITEM%TYPE;
   V_VRTTTXAERO    ITEMPRODUTO.VRUNITITEM%TYPE;
   V_VRTTTXAEME    ITEMPRODUTO.VRUNITITEM%TYPE;

   V_CDPRODUTO     PARAMCOMIS.CDPRODUTO%TYPE;
   V_NMPRODUTO     PRODUTO.NMPRODUTO%TYPE;
	V_CDPRAEROIN    PARAMCOMIS.CDPRAEROIN%TYPE;
   V_NMPRAEROIN    PRODUTO.NMPRODUTO%TYPE;
   V_IDNACSERV     VARCHAR2(01);

   V_CDSERVICO     ITEMPRODUTO.CDPRODEMIS%TYPE;
   V_NRLANCTONFANT NOTAFISCAL.NRLANCTONF%TYPE;
   V_SEQUENCIAL    ITEMPRODUTO.NRSEQITPROD%TYPE;

BEGIN

   SELECT CDCLIENTE
   INTO V_CDCLIENTE
   FROM COMPANHIA
   WHERE CDCIA = P_CDCIA;

   SELECT CDEMPRESA, CDINSCMUNI, CDINSCESTA
   INTO V_CDEMPRESA, V_CDINSCMUNI, V_CDINSCESTA
   FROM FILIAL
   WHERE CDFILIAL = P_FILIAL;

   SELECT IDTPIJURCLIE, NRINSJURCLIE
   INTO V_IDTPIJURCLIE, V_NRINSJURCLIE
   FROM CLIENTE
   WHERE CDCLIENTE = V_CDCLIENTE;

   SELECT NVL(NRMAXITNF, 10), NVL(NRMAXSERVNF, 5),
          IDCONMAXITEM  
   INTO V_NRMAXITNF, V_NRMAXSERVNF, V_IDCONMAXITEM
   FROM SERIENF
   WHERE CDEMPRESA  = V_CDEMPRESA  AND
         CDINSCESTA = V_CDINSCESTA AND
         CDINSCMUNI = V_CDINSCMUNI AND
         CDSERIE    = P_CDSERIE;

   V_NRLANCTONF := 'X';
   V_CDFISCOPER := 'X';
   V_NRDELIVERY := -1;
   V_IDSERVICO  := 'X';
   V_VRCOTDOLAR := -1;
   V_IDPRODSERV := 'X';

   V_NRSEQITPROD := 0;

   V_NOVANOTA := 'X';

   V_VRDESCDEL := 0;
   V_VRDESCSRV := 0;

   V_NRCOUNTPR   := 0;
   V_NRCOUNTSV   := 0;

   V_VRTTTXAERO  := 0;
   V_VRTTTXAEME  := 0;

   FOR CURS_APDELIVERY IN
      (SELECT CDCIAAP, VRCOTDOLARAP, NRDELIVERYAP, CDFISCOPERAP, CDSUFXCFOPAP, IDSERVICOAP,
              CDSERVICOAP, CDPRODUTOAP, DSSERVFATUAP, VRPUREASERVAP,
              VRPUDOLSERVAP, SUM(NRQTDESERVAP) NRTOTASERVAP,
              NVL(SUM(VRDESCDELAP),0) VRDESCDELAP, NVL(SUM(VRDESCSRVAP),0) VRDESCSRVAP,
              IDTIPMANUALAP, IDPRODSERVAP
       FROM TRAB_APURAC
       WHERE CDCIAAP       = P_CDCIA  AND
             CDFILIALAP    = P_FILIPROC AND
             NRAPURACFATAP = P_NRAPURACFAT
       GROUP BY CDCIAAP, NRDELIVERYAP, IDTIPMANUALAP, IDPRODSERVAP, VRCOTDOLARAP, CDFISCOPERAP,
                CDSUFXCFOPAP, IDSERVICOAP, CDSERVICOAP, CDPRODUTOAP, DSSERVFATUAP,
                VRPUREASERVAP, VRPUDOLSERVAP) LOOP

       --Se A Delivery for Nacional  
       IF CURS_APDELIVERY.IDTIPMANUALAP = '1' THEN
       
          /************************************************************************************************************************
            Gera uma Nova Nota fiscal em um dos casos:
          
              1. Estiver apurando o primeiro servio (Primeiro dado do Cursor)
              2. For uma nova Delivery (No faturamento por Delivery com separao de produtos e servios, uma nova NF  gerada 
                 a cada Delivery, com os produtos ou servios da mesma)
              3. Separa as NFs de Produto e de Servios, para uma mesma Delivery (Cada delivery origina duas NFs)
              4. For um Produto e tiver alcanado o mximo de Produtos em uma NF, e controlar quantidade maxima de Intens na NF
              5. For um Servio e tiver alcanado o mximo de Servios em uma NF, e controlar quantidade maxima de Intens na NF
                            
           *************************************************************************************************************************/
          IF (CURS_APDELIVERY.CDFISCOPERAP <> V_CDFISCOPER) OR
             (CURS_APDELIVERY.NRDELIVERYAP <> V_NRDELIVERY) OR
             (CURS_APDELIVERY.IDPRODSERVAP <> V_IDPRODSERV) OR
             (((V_NRCOUNTPR = V_NRMAXITNF)   AND (CURS_APDELIVERY.IDPRODSERVAP = 'P')) OR
              ((V_NRCOUNTSV = V_NRMAXSERVNF) AND (CURS_APDELIVERY.IDPRODSERVAP = 'S'))) THEN

             IF (V_NOVANOTA <> 'X') THEN
                /* Isto indica que j houve uma gravao de outra nota
                   anteriormente sendo ento necessrio o clculo dos impostos
                   da mesma */

                CALCULA_DESCONTOS(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_NRAPURACFAT);

                V_VRTTTXAERO  := V_VRTTTXAERO + NVL(V_VRTAXAAERO,0);
                V_VRTTTXAEME  := V_VRTTTXAEME + NVL(V_VRTAXAAEME,0);

                IF (CURS_APDELIVERY.NRDELIVERYAP <> V_NRDELIVERY) THEN

                   SELECT MAX(PR.CDPRODUTO), MAX(PR.CDPRAEROIN), MAX(P.NMPRODUTO), MAX(I.NMPRODUTO)
                   INTO V_CDPRODUTO, V_CDPRAEROIN, V_NMPRODUTO, V_NMPRAEROIN
                   FROM PARAMCOMIS PR, PRODUTO P, PRODUTO I
                   WHERE PR.CDPRODUTO  = P.CDPRODUTO AND
                         PR.CDPRAEROIN = I.CDPRODUTO AND
                         PR.CDFILIAL   = P_FILIAL;

                   SELECT MAX(SUBSTR(CDPRODEMIS,1,1))
                   INTO V_IDNACSERV
                   FROM ITEMPRODUTO
                   WHERE CDFILIAL   = P_FILIPROC AND
                         NRLANCTONF = V_NRLANCTONF;

                   IF V_IDNACSERV = '2' THEN
                      V_CDPRODUTO := V_CDPRAEROIN;
                      V_NMPRODUTO := V_NMPRAEROIN;
                   END IF;

                   IF V_IDPRODSERV = 'S' THEN
                      V_NRSEQITPROD := V_NRSEQITPROD + 1;

                      SELECT MAX(NRSEQITPROD)
                      INTO V_SEQUENCIAL
                      FROM ITEMPRODUTO
                      WHERE CDFILIAL   = P_FILIAL     AND
                            NRLANCTONF = V_NRLANCTONF AND
                            CDPRODUTO  = V_CDPRODUTO;

                      IF (V_SEQUENCIAL IS NOT NULL) THEN
                         UPDATE ITEMPRODUTO
                         SET VRUNITITEM    = VRUNITITEM   + V_VRTTTXAERO,
                             VRTOTAITEM    = VRTOTAITEM   + V_VRTTTXAERO,
                             VRCONTITEM    = VRCONTITEM   + V_VRTTTXAERO,
                             VRBRUTITEM    = VRBRUTITEM   + V_VRTTTXAERO,
                             VRITMOEDESTR  = VRITMOEDESTR + V_VRTTTXAEME
                         WHERE CDFILIAL    = P_FILIAL     AND
                               NRLANCTONF  = V_NRLANCTONF AND
                               NRSEQITPROD = V_SEQUENCIAL;

                      ELSE
                         INSERT INTO ITEMPRODUTO (CDFILIAL, NRLANCTONF, NRSEQITPROD,
                                                  CDPRODUTO, CDPRODEMIS,
                                                  DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                                  VRUNITITEM, VRDESCITEM,
                                                  VRTOTAITEM,
                                                  VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                                  IDCONFORITEM, IDERROSITEM, IDAVISOSITEM)
                         VALUES (P_FILIAL, V_NRLANCTONF, LPAD(TO_CHAR(V_NRSEQITPROD),4,'0'),
                                 V_CDPRODUTO, '1'||V_CDPRODUTO,
                                 V_NMPRODUTO, 'N', 1,
                                 V_VRTTTXAERO, 0,
                                 V_VRTTTXAERO,
                                 V_VRTTTXAERO,
                                 V_VRTTTXAERO,
                                 V_VRTTTXAEME,
                                 'N', '00000','00000');
                      END IF;

                      APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                                  P_DTINIAPUR, P_DTFIMAPUR);
                   ELSE
                      APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                                  P_DTINIAPUR, P_DTFIMAPUR);

                      V_NRLANCTONFANT := V_NRLANCTONF;

                      NOVO_CODIGO('LANCNF/FILIAL' || P_FILIPROC,V_NRLANCTONF);
                      V_NRLANCTONF  := SUBSTR(V_NRLANCTONF, 11, 10);


                      INSERT INTO NOTAFISCAL (CDFILIAL, NRLANCTONF, CDEMPRESA,
                                              CDINSCESTA, CDINSCMUNI, CDFILIEMIT,
                                              CDFILIRECE, IDTPIJURNF, NRINSJURNF,
                                              CDFORNECED, CDCLIENTE, IDERROS, IDAVISOS,
                                              IDBLOQUEADO, IDDOCFISCAL, IDDOCFINANC,
                                              NRNOTAFISC, DTENTRSAID,
                                              VRPRODUTOS, VRNOTAFISC, DTINIAPUFISC,
                                              DTAPROVACAO, CDOPERAPRO, DTCONTABIL,
                                              NRPLACAVEIC, SGUFVEIC, IDPGTOFRETE,
                                              DSQTDEVOLU, DSESPECVOLU, DSMARCAVOLU,
                                              DSNUMEVOLU, VRPBRUTOVOLU, VRPLIQUVOLU,
                                              IDENTRSAIDOP, CDTIPOOPER, CDSERIE, IDTPIJURTRAN,
                                              NRINSJURTRAN, VRTTMOEDESTR, IDSTATUS,
                                              IDSISTEMA, IDDOCFATUR, NRAPURACFAT, IDORIGDESTNF)
                      VALUES (P_FILIPROC, V_NRLANCTONF, V_CDEMPRESA,
                              V_CDINSCESTA, V_CDINSCMUNI, P_FILIAL,
                              NULL, V_IDTPIJURCLIE, V_NRINSJURCLIE,
                              NULL, V_CDCLIENTE, NULL, NULL,
                              'N', 'N', 'N',
                              ' ', P_DTFECHAME,
                              0, 0, P_DTINIAPUR,
                              NULL, NULL, NULL,
                              NULL, NULL, NULL,
                              NULL, NULL, NULL,
                              NULL, 0, 0,
                              'S', '01', P_CDSERIE, P_IDTPIJURTRAN,
                              P_NRINSJURTRAN, 0, 'P', 'FAC', 'S', P_NRAPURACFAT, 'C');

                      INSERT INTO ITEMPRODUTO (CDFILIAL, NRLANCTONF, NRSEQITPROD,
                                               CDPRODUTO, CDPRODEMIS,
                                               DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                               VRUNITITEM, VRDESCITEM,
                                               VRTOTAITEM,
                                               VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                               IDCONFORITEM, IDERROSITEM, IDAVISOSITEM)
                      VALUES (P_FILIPROC, V_NRLANCTONF, '0001',
                              V_CDPRODUTO, '1'||V_CDPRODUTO,
                              V_NMPRODUTO, 'N', 1,
                              V_VRTTTXAERO, 0,
                              V_VRTTTXAERO,
                              V_VRTTTXAERO,
                              V_VRTTTXAERO,
                              V_VRTTTXAEME,
                              'N', '00000','00000');

                      APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                                  P_DTINIAPUR, P_DTFIMAPUR);

                      SELECT MAX(CDPRODEMIS)
                      INTO V_CDSERVICO
                      FROM ITEMPRODUTO
                      WHERE CDFILIAL   = P_FILIAL AND
                            NRLANCTONF = V_NRLANCTONFANT;

                      UPDATE TRAB_APURAC
                      SET NRLANCTONFAP = V_NRLANCTONF
                      WHERE CDCIAAP       = P_CDCIA       AND
                            CDFILIALAP    = P_FILIAL      AND
                            NRAPURACFATAP = P_NRAPURACFAT AND
                            CDSERVICOAP   = V_CDSERVICO   AND
                            NRDELIVERYAP  = V_NRDELIVERY  AND
                            NRLANCTONFAP  = V_NRLANCTONFANT;
                   END IF;
                   V_VRTTTXAERO  := 0;
                   V_VRTTTXAEME  := 0;
                ELSE
                   APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                               P_DTINIAPUR, P_DTFIMAPUR);
                END IF;
             END IF;

             IF (CURS_APDELIVERY.NRDELIVERYAP <> V_NRDELIVERY) THEN
                SELECT NVL(MAX(VRDESCDELAP),0), NVL(MAX(VRDESCSRVAP),0)
                INTO V_VRDESCDEL, V_VRDESCSRV
                FROM TRAB_APURAC
                WHERE CDCIAAP       = P_CDCIA                       AND
                      CDFILIALAP    = P_FILIPROC                      AND
                      NRAPURACFATAP = P_NRAPURACFAT                 AND
                      (NRDELIVERYAP = CURS_APDELIVERY.NRDELIVERYAP) AND
                      ((VRDESCDELAP  <> 0) OR (VRDESCSRVAP <> 0));
             END IF;

             V_NOVANOTA  := ' ';
             V_NRCOUNTPR := 0;
             V_NRCOUNTSV := 0;

             /* a procedure novo_codigo gera o novo sequencial e tambem
                confirma a incluso da nota anterior, pois existe um COMMIT
                dentro da novo_codigo */

             NOVO_CODIGO('LANCNF/FILIAL' || P_FILIPROC,V_NRLANCTONF);
             V_NRLANCTONF  := SUBSTR(V_NRLANCTONF, 11, 10);

             V_NRSEQITPROD := 0;

             V_CDFISCOPER  := CURS_APDELIVERY.CDFISCOPERAP;
             V_NRDELIVERY  := CURS_APDELIVERY.NRDELIVERYAP;
             V_IDSERVICO   := CURS_APDELIVERY.IDSERVICOAP;
             V_IDPRODSERV  := CURS_APDELIVERY.IDPRODSERVAP;

             INSERT INTO NOTAFISCAL (CDFILIAL, NRLANCTONF, CDEMPRESA,
                                     CDINSCESTA, CDINSCMUNI, CDFILIEMIT,
                                     CDFILIRECE, IDTPIJURNF, NRINSJURNF,
                                     CDFORNECED, CDCLIENTE, IDERROS, IDAVISOS,
                                     IDBLOQUEADO, IDDOCFISCAL, IDDOCFINANC,
                                     NRNOTAFISC, DTENTRSAID,
                                     VRPRODUTOS, VRNOTAFISC, DTINIAPUFISC,
                                     DTAPROVACAO, CDOPERAPRO, DTCONTABIL,
                                     NRPLACAVEIC, SGUFVEIC, IDPGTOFRETE,
                                     DSQTDEVOLU, DSESPECVOLU, DSMARCAVOLU,
                                     DSNUMEVOLU, VRPBRUTOVOLU, VRPLIQUVOLU,
                                     IDENTRSAIDOP, CDTIPOOPER, CDSERIE, IDTPIJURTRAN,
                                     NRINSJURTRAN, VRTTMOEDESTR, IDSTATUS,
                                     IDSISTEMA, IDDOCFATUR, NRAPURACFAT, IDORIGDESTNF)
             VALUES (P_FILIPROC, V_NRLANCTONF, V_CDEMPRESA,
                     V_CDINSCESTA, V_CDINSCMUNI, P_FILIAL,
                     NULL, V_IDTPIJURCLIE, V_NRINSJURCLIE,
                     NULL, V_CDCLIENTE, NULL, NULL,
                     'N', 'N', 'N',
                     ' ', P_DTFECHAME,
                     0, 0, P_DTINIAPUR,
                     NULL, NULL, NULL,
                     NULL, NULL, NULL,
                     NULL, NULL, NULL,
                     NULL, 0, 0,
                     'S', '01', P_CDSERIE, P_IDTPIJURTRAN,
                     P_NRINSJURTRAN, 0, 'P', 'FAC', 'S', P_NRAPURACFAT, 'C');
          END IF;

          V_NRSEQITPROD := V_NRSEQITPROD + 1;

          INSERT INTO ITEMPRODUTO (CDFILIAL, NRSEQITPROD,
                                   CDPRODUTO, CDPRODEMIS,
                                   DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                   VRUNITITEM, VRDESCITEM, VRTOTAITEM,
                                   VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                   IDCONFORITEM, NRLANCTONF, CDFISOPEITEM,
                                   CDSUFXCFOPPR,
                                   IDERROSITEM, IDAVISOSITEM)
          VALUES (P_FILIPROC, LPAD(TO_CHAR(V_NRSEQITPROD),4,'0'),
                  CURS_APDELIVERY.CDPRODUTOAP, CURS_APDELIVERY.IDTIPMANUALAP||CURS_APDELIVERY.CDSERVICOAP,
                  CURS_APDELIVERY.DSSERVFATUAP, 'N', CURS_APDELIVERY.NRTOTASERVAP,
                  CURS_APDELIVERY.VRPUREASERVAP, 0,
                  ROUND(CURS_APDELIVERY.NRTOTASERVAP * CURS_APDELIVERY.VRPUREASERVAP,2),
                  ROUND(CURS_APDELIVERY.NRTOTASERVAP * CURS_APDELIVERY.VRPUREASERVAP,2),
                  ROUND(CURS_APDELIVERY.NRTOTASERVAP * CURS_APDELIVERY.VRPUREASERVAP,2), 0,
                  'N', V_NRLANCTONF, CURS_APDELIVERY.CDFISCOPERAP,
                  CURS_APDELIVERY.CDSUFXCFOPAP, '00000','00000');

          UPDATE TRAB_APURAC
          SET NRLANCTONFAP = V_NRLANCTONF
          WHERE CDCIAAP        = P_CDCIA                       AND
                CDFILIALAP     = P_FILIPROC                      AND
                NRAPURACFATAP  = P_NRAPURACFAT                 AND
                CDSERVICOAP    = CURS_APDELIVERY.CDSERVICOAP   AND
                NRDELIVERYAP   = CURS_APDELIVERY.NRDELIVERYAP  AND
                CDPRODUTOAP    = CURS_APDELIVERY.CDPRODUTOAP   AND
                IDTIPMANUALAP  = CURS_APDELIVERY.IDTIPMANUALAP AND
                (CDFISCOPERAP  = CURS_APDELIVERY.CDFISCOPERAP  OR
                 CURS_APDELIVERY.CDFISCOPERAP IS NULL)         AND
                (CDSUFXCFOPAP  = CURS_APDELIVERY.CDSUFXCFOPAP  OR
                 CURS_APDELIVERY.CDSUFXCFOPAP IS NULL)         AND
                (VRPUREASERVAP = CURS_APDELIVERY.VRPUREASERVAP OR
                 CURS_APDELIVERY.VRPUREASERVAP IS NULL)        AND
                NRLANCTONFAP IS NULL;


          IF CURS_APDELIVERY.IDPRODSERVAP = 'S' THEN
             V_NRCOUNTSV := V_NRCOUNTSV + 1;
          ELSE
             V_NRCOUNTPR := V_NRCOUNTPR + 1;
          END IF;

      --Se A Delivery for Internacional (Faturamento em Dolar)  
      ELSIF CURS_APDELIVERY.IDTIPMANUALAP = '2' THEN
      
         /************************************************************************************************************************
            Gera uma Nova Nota fiscal em um dos casos:
          
              1. Estiver apurando o primeiro servio (Primeiro dado do Cursor)
              2. For uma nova Delivery (No faturamento por Delivery com separao de produtos e servios, uma nova NF  gerada 
                 a cada Delivery, com os produtos ou servios da mesma)
              3. Separa as NFs de Produto e de Servios, para uma mesma Delivery (Cada delivery origina duas NFs)
              4. A cotao do dolar mudar de uma linha do cursor para a outra
              5. For um Produto e tiver alcanado o mximo de Produtos em uma NF, e controlar quantidade maxima de Intens na NF
              6. For um Servio e tiver alcanado o mximo de Servios em uma NF, e controlar quantidade maxima de Intens na NF
              
           *************************************************************************************************************************/
         IF (CURS_APDELIVERY.CDFISCOPERAP <> V_CDFISCOPER) OR
            (CURS_APDELIVERY.NRDELIVERYAP <> V_NRDELIVERY) OR
            (CURS_APDELIVERY.VRCOTDOLARAP <> V_VRCOTDOLAR) OR
            (CURS_APDELIVERY.IDPRODSERVAP <> V_IDPRODSERV) OR
            (((V_NRCOUNTPR = V_NRMAXITNF)   AND (CURS_APDELIVERY.IDPRODSERVAP = 'P')) OR
             ((V_NRCOUNTSV = V_NRMAXSERVNF) AND (CURS_APDELIVERY.IDPRODSERVAP = 'S'))) THEN

             IF (V_NOVANOTA <> 'X') THEN
                /* Isto indica que j houve uma gravao de outra nota
                   anteriormente sendo ento necessrio o clculo dos impostos
                   da mesma */

                CALCULA_DESCONTOS(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_NRAPURACFAT);

                V_VRTTTXAERO  := V_VRTTTXAERO + NVL(V_VRTAXAAERO,0);
                V_VRTTTXAEME  := V_VRTTTXAEME + NVL(V_VRTAXAAEME,0);

                IF (CURS_APDELIVERY.NRDELIVERYAP <> V_NRDELIVERY) THEN

                   SELECT MAX(PR.CDPRODUTO), MAX(PR.CDPRAEROIN), MAX(P.NMPRODUTO), MAX(I.NMPRODUTO)
                   INTO V_CDPRODUTO, V_CDPRAEROIN, V_NMPRODUTO, V_NMPRAEROIN
                   FROM PARAMCOMIS PR, PRODUTO P, PRODUTO I
                   WHERE PR.CDPRODUTO  = P.CDPRODUTO AND
                         PR.CDPRAEROIN = I.CDPRODUTO AND
                         PR.CDFILIAL   = P_FILIAL;

                   SELECT MAX(SUBSTR(CDPRODEMIS,1,1))
                   INTO V_IDNACSERV
                   FROM ITEMPRODUTO
                   WHERE CDFILIAL   = P_FILIPROC AND
                         NRLANCTONF = V_NRLANCTONF;

                   IF V_IDNACSERV = '2' THEN
                      V_CDPRODUTO := V_CDPRAEROIN;
                      V_NMPRODUTO := V_NMPRAEROIN;
                   END IF;

                   IF V_IDPRODSERV = 'S' THEN
                      V_NRSEQITPROD := V_NRSEQITPROD + 1;

                      SELECT MAX(NRSEQITPROD)
                      INTO V_SEQUENCIAL
                      FROM ITEMPRODUTO
                      WHERE CDFILIAL   = P_FILIAL     AND
                            NRLANCTONF = V_NRLANCTONF AND
                            CDPRODUTO  = V_CDPRODUTO;

                      IF (V_SEQUENCIAL IS NOT NULL) THEN
                         UPDATE ITEMPRODUTO
                         SET VRUNITITEM    = VRUNITITEM   + V_VRTTTXAERO,
                             VRTOTAITEM    = VRTOTAITEM   + V_VRTTTXAERO,
                             VRCONTITEM    = VRCONTITEM   + V_VRTTTXAERO,
                             VRBRUTITEM    = VRBRUTITEM   + V_VRTTTXAERO,
                             VRITMOEDESTR  = VRITMOEDESTR + V_VRTTTXAEME
                         WHERE CDFILIAL    = P_FILIAL     AND
                               NRLANCTONF  = V_NRLANCTONF AND
                               NRSEQITPROD = V_SEQUENCIAL;

                      ELSE
                         INSERT INTO ITEMPRODUTO (CDFILIAL, NRLANCTONF, NRSEQITPROD,
                                                  CDPRODUTO, CDPRODEMIS,
                                                  DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                                  VRUNITITEM, VRDESCITEM,
                                                  VRTOTAITEM,
                                                  VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                                  IDCONFORITEM, IDERROSITEM, IDAVISOSITEM)
                         VALUES (P_FILIAL, V_NRLANCTONF, LPAD(TO_CHAR(V_NRSEQITPROD),4,'0'),
                                 V_CDPRODUTO, '1'||V_CDPRODUTO,
                                 V_NMPRODUTO, 'N', 1,
                                 V_VRTTTXAERO, 0,
                                 V_VRTTTXAERO,
                                 V_VRTTTXAERO,
                                 V_VRTTTXAERO,
                                 V_VRTTTXAEME,
                                 'N', '00000','00000');
                      END IF;

                      APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                                  P_DTINIAPUR, P_DTFIMAPUR);
                   ELSE
                      APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                                  P_DTINIAPUR, P_DTFIMAPUR);

                      V_NRLANCTONFANT := V_NRLANCTONF;

                      NOVO_CODIGO('LANCNF/FILIAL' || P_FILIPROC,V_NRLANCTONF);
                      V_NRLANCTONF  := SUBSTR(V_NRLANCTONF, 11, 10);

                      INSERT INTO NOTAFISCAL (CDFILIAL, NRLANCTONF, CDEMPRESA,
                                              CDINSCESTA, CDINSCMUNI, CDFILIEMIT,
                                              CDFILIRECE, IDTPIJURNF, NRINSJURNF,
                                              CDFORNECED, CDCLIENTE, IDERROS, IDAVISOS,
                                              IDBLOQUEADO, IDDOCFISCAL, IDDOCFINANC,
                                              NRNOTAFISC, DTENTRSAID,
                                              VRPRODUTOS, VRNOTAFISC, DTINIAPUFISC,
                                              DTAPROVACAO, CDOPERAPRO, DTCONTABIL,
                                              NRPLACAVEIC, SGUFVEIC, IDPGTOFRETE,
                                              DSQTDEVOLU, DSESPECVOLU, DSMARCAVOLU,
                                              DSNUMEVOLU, VRPBRUTOVOLU, VRPLIQUVOLU,
                                              IDENTRSAIDOP, CDTIPOOPER, CDSERIE, IDTPIJURTRAN,
                                              NRINSJURTRAN, VRTTMOEDESTR, IDSTATUS,
                                              IDSISTEMA, IDDOCFATUR, NRAPURACFAT, IDORIGDESTNF)
                      VALUES (P_FILIPROC, V_NRLANCTONF, V_CDEMPRESA,
                              V_CDINSCESTA, V_CDINSCMUNI, P_FILIAL,
                              NULL, V_IDTPIJURCLIE, V_NRINSJURCLIE,
                              NULL, V_CDCLIENTE, NULL, NULL,
                              'N', 'N', 'N',
                              ' ', P_DTFECHAME,
                              0, 0, P_DTINIAPUR,
                              NULL, NULL, NULL,
                              NULL, NULL, NULL,
                              NULL, NULL, NULL,
                              NULL, 0, 0,
                              'S', '01', P_CDSERIE, P_IDTPIJURTRAN,
                              P_NRINSJURTRAN, 0, 'P', 'FAC', 'S', P_NRAPURACFAT, 'C');

                      INSERT INTO ITEMPRODUTO (CDFILIAL, NRLANCTONF, NRSEQITPROD,
                                               CDPRODUTO, CDPRODEMIS,
                                               DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                               VRUNITITEM, VRDESCITEM,
                                               VRTOTAITEM,
                                               VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                               IDCONFORITEM, IDERROSITEM, IDAVISOSITEM)
                      VALUES (P_FILIPROC, V_NRLANCTONF, '0001',
                              V_CDPRODUTO, '1'||V_CDPRODUTO,
                              V_NMPRODUTO, 'N', 1,
                              V_VRTTTXAERO, 0,
                              V_VRTTTXAERO,
                              V_VRTTTXAERO,
                              V_VRTTTXAERO,
                              V_VRTTTXAEME,
                              'N', '00000','00000');

                      APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                                  P_DTINIAPUR, P_DTFIMAPUR);

                      SELECT MAX(CDPRODEMIS)
                      INTO V_CDSERVICO
                      FROM ITEMPRODUTO
                      WHERE CDFILIAL   = P_FILIAL AND
                            NRLANCTONF = V_NRLANCTONFANT;

                      UPDATE TRAB_APURAC
                      SET NRLANCTONFAP = V_NRLANCTONF
                      WHERE CDCIAAP       = P_CDCIA       AND
                            CDFILIALAP    = P_FILIAL      AND
                            NRAPURACFATAP = P_NRAPURACFAT AND
                            CDSERVICOAP   = V_CDSERVICO   AND
                            NRDELIVERYAP  = V_NRDELIVERY  AND
                            NRLANCTONFAP  = V_NRLANCTONFANT;
                   END IF;
                   V_VRTTTXAERO  := 0;
                   V_VRTTTXAEME  := 0;
                ELSE
                   APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                               P_DTINIAPUR, P_DTFIMAPUR);
                END IF;
            END IF;

            IF (CURS_APDELIVERY.NRDELIVERYAP <> V_NRDELIVERY) THEN
               SELECT NVL(MAX(VRDESCDELAP),0), NVL(MAX(VRDESCSRVAP),0)
               INTO V_VRDESCDEL, V_VRDESCSRV
               FROM TRAB_APURAC
               WHERE CDCIAAP       = P_CDCIA                       AND
                     CDFILIALAP    = P_FILIPROC                      AND
                     NRAPURACFATAP = P_NRAPURACFAT                 AND
                     (NRDELIVERYAP = CURS_APDELIVERY.NRDELIVERYAP) AND
                     ((VRDESCDELAP  <> 0) OR (VRDESCSRVAP <> 0));
            END IF;

            V_NOVANOTA  := ' ';
            V_NRCOUNTPR := 0;
            V_NRCOUNTSV := 0;

            /* a procedure novo_codigo gera o novo sequencial e tambem
               confirma a incluso da nota anterior, pois existe um COMMIT
               dentro da novo_codigo */

            NOVO_CODIGO('LANCNF/FILIAL' || P_FILIPROC,V_NRLANCTONF);
            V_NRLANCTONF  := SUBSTR(V_NRLANCTONF, 11, 10);

            V_NRSEQITPROD := 0;

            V_CDFISCOPER  := CURS_APDELIVERY.CDFISCOPERAP;
            V_NRDELIVERY  := CURS_APDELIVERY.NRDELIVERYAP;
            V_VRCOTDOLAR  := CURS_APDELIVERY.VRCOTDOLARAP;
            V_IDSERVICO   := CURS_APDELIVERY.IDSERVICOAP;
            V_IDPRODSERV  := CURS_APDELIVERY.IDPRODSERVAP;

            INSERT INTO NOTAFISCAL (CDFILIAL, NRLANCTONF, CDEMPRESA,
                                    CDINSCESTA, CDINSCMUNI, CDFILIEMIT,
                                    CDFILIRECE, IDTPIJURNF, NRINSJURNF,
                                    CDFORNECED, CDCLIENTE, IDERROS, IDAVISOS,
                                    IDBLOQUEADO, IDDOCFISCAL, IDDOCFINANC,
                                    NRNOTAFISC, DTENTRSAID,
                                    VRPRODUTOS, VRNOTAFISC, DTINIAPUFISC,
                                    DTAPROVACAO, CDOPERAPRO, DTCONTABIL,
                                    NRPLACAVEIC, SGUFVEIC, IDPGTOFRETE,
                                    DSQTDEVOLU, DSESPECVOLU, DSMARCAVOLU,
                                    DSNUMEVOLU, VRPBRUTOVOLU, VRPLIQUVOLU,
                                    IDENTRSAIDOP, CDTIPOOPER, CDSERIE, IDTPIJURTRAN,
                                    NRINSJURTRAN, VRTTMOEDESTR, IDSTATUS,
                                    IDSISTEMA, IDDOCFATUR, NRAPURACFAT, IDORIGDESTNF)
            VALUES (P_FILIPROC, V_NRLANCTONF, V_CDEMPRESA,
                    V_CDINSCESTA, V_CDINSCMUNI, P_FILIAL,
                    NULL, V_IDTPIJURCLIE, V_NRINSJURCLIE,
                    NULL, V_CDCLIENTE, NULL, NULL,
                    'N', 'N', 'N',
                    ' ', P_DTFECHAME,
                    0, 0, P_DTINIAPUR,
                    NULL, NULL, NULL,
                    NULL, NULL, NULL,
                    NULL, NULL, NULL,
                    NULL, 0, 0,
                    'S', '01', P_CDSERIE, P_IDTPIJURTRAN,
                    P_NRINSJURTRAN, 0, 'P', 'FAC', 'S', P_NRAPURACFAT, 'C');
         END IF;

         V_NRSEQITPROD := V_NRSEQITPROD + 1;

         V_VRINDICE := CURS_APDELIVERY.VRCOTDOLARAP;

         IF V_VRINDICE IS NULL THEN
            raise_application_error(-20501, 'ndice financeiro no cadastrado para a companhia.', True);
         END IF;

         V_VRUNITITEM := CURS_APDELIVERY.VRPUDOLSERVAP * V_VRINDICE;

         INSERT INTO ITEMPRODUTO (CDFILIAL, NRSEQITPROD,
                                  CDPRODUTO, CDPRODEMIS,
                                  DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                  VRUNITITEM, VRDESCITEM, VRTOTAITEM,
                                  VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                  IDCONFORITEM, NRLANCTONF, CDFISOPEITEM,
                                  CDSUFXCFOPPR,
                                  IDERROSITEM, IDAVISOSITEM)
         VALUES (P_FILIPROC, LPAD(TO_CHAR(V_NRSEQITPROD),4,'0'),
                 CURS_APDELIVERY.CDPRODUTOAP, CURS_APDELIVERY.IDTIPMANUALAP||CURS_APDELIVERY.CDSERVICOAP,
                 CURS_APDELIVERY.DSSERVFATUAP, 'N', CURS_APDELIVERY.NRTOTASERVAP,
                 V_VRUNITITEM, 0,
                 ROUND(CURS_APDELIVERY.NRTOTASERVAP * V_VRUNITITEM,2),
                 ROUND(CURS_APDELIVERY.NRTOTASERVAP * V_VRUNITITEM,2),
                 ROUND(CURS_APDELIVERY.NRTOTASERVAP * V_VRUNITITEM,2),
                 ROUND(CURS_APDELIVERY.NRTOTASERVAP * CURS_APDELIVERY.VRPUDOLSERVAP,2),
                 'N', V_NRLANCTONF, CURS_APDELIVERY.CDFISCOPERAP,
                 CURS_APDELIVERY.CDSUFXCFOPAP, '00000','00000');

          UPDATE TRAB_APURAC
          SET NRLANCTONFAP = V_NRLANCTONF
          WHERE CDCIAAP        = P_CDCIA                       AND
                CDFILIALAP     = P_FILIPROC                      AND
                NRAPURACFATAP  = P_NRAPURACFAT                 AND
                CDSERVICOAP    = CURS_APDELIVERY.CDSERVICOAP   AND
                NRDELIVERYAP   = CURS_APDELIVERY.NRDELIVERYAP  AND
                CDPRODUTOAP    = CURS_APDELIVERY.CDPRODUTOAP   AND
                IDTIPMANUALAP  = CURS_APDELIVERY.IDTIPMANUALAP AND
                (VRCOTDOLARAP  = CURS_APDELIVERY.VRCOTDOLARAP  OR
                 CURS_APDELIVERY.VRCOTDOLARAP IS NULL)         AND
                (CDFISCOPERAP  = CURS_APDELIVERY.CDFISCOPERAP  OR
                 CURS_APDELIVERY.CDFISCOPERAP IS NULL)         AND
                (CDSUFXCFOPAP  = CURS_APDELIVERY.CDSUFXCFOPAP  OR
                 CURS_APDELIVERY.CDSUFXCFOPAP IS NULL)         AND
                (VRPUDOLSERVAP = CURS_APDELIVERY.VRPUDOLSERVAP OR
                 CURS_APDELIVERY.VRPUDOLSERVAP IS NULL)        AND
                NRLANCTONFAP IS NULL;

          IF CURS_APDELIVERY.IDPRODSERVAP = 'S' THEN
             V_NRCOUNTSV := V_NRCOUNTSV + 1;
          ELSE
             V_NRCOUNTPR := V_NRCOUNTPR + 1;
          END IF;
      END IF;
   END LOOP;

   IF (V_NOVANOTA <> 'X') THEN
      /* Isto indica que j houve uma gravao de outra nota
         anteriormente sendo ento necessrio o clculo dos impostos
         da ltima nota fechada */

      UPDATE TRAB_APURAC
      SET NRLANCTONFAP = V_NRLANCTONF
      WHERE CDCIAAP        = P_CDCIA        AND
            CDFILIALAP     = P_FILIPROC       AND
            NRAPURACFATAP  = P_NRAPURACFAT  AND
            (CDFISCOPERAP = V_CDFISCOPER)   AND
            (NRDELIVERYAP = V_NRDELIVERY)   AND
            (IDPRODSERVAP = V_IDPRODSERV)   AND
            (CDSERVICOAP  IN (SELECT SUBSTR(CDPRODEMIS,2,10)
                              FROM ITEMPRODUTO
                              WHERE CDFILIAL   = P_FILIPROC AND
                                    NRLANCTONF = V_NRLANCTONF)) AND
            (NRLANCTONFAP IS NULL);

      CALCULA_DESCONTOS(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_NRAPURACFAT);

      V_VRTTTXAERO  := V_VRTTTXAERO + NVL(V_VRTAXAAERO,0);
      V_VRTTTXAEME  := V_VRTTTXAEME + NVL(V_VRTAXAAEME,0);

      SELECT MAX(PR.CDPRODUTO), MAX(PR.CDPRAEROIN), MAX(P.NMPRODUTO), MAX(I.NMPRODUTO)
      INTO V_CDPRODUTO, V_CDPRAEROIN, V_NMPRODUTO, V_NMPRAEROIN
      FROM PARAMCOMIS PR, PRODUTO P, PRODUTO I
      WHERE PR.CDPRODUTO  = P.CDPRODUTO AND
            PR.CDPRAEROIN = I.CDPRODUTO AND
            PR.CDFILIAL   = P_FILIAL;

      SELECT MAX(SUBSTR(CDPRODEMIS,1,1))
      INTO V_IDNACSERV
      FROM ITEMPRODUTO
      WHERE CDFILIAL   = P_FILIPROC AND
            NRLANCTONF = V_NRLANCTONF;

      IF V_IDNACSERV = '2' THEN
         V_CDPRODUTO := V_CDPRAEROIN;
         V_NMPRODUTO := V_NMPRAEROIN;
      END IF;

      IF V_IDPRODSERV = 'S' THEN
         V_NRSEQITPROD := V_NRSEQITPROD + 1;

         SELECT MAX(NRSEQITPROD)
         INTO V_SEQUENCIAL
         FROM ITEMPRODUTO
         WHERE CDFILIAL   = P_FILIAL     AND
               NRLANCTONF = V_NRLANCTONF AND
               CDPRODUTO  = V_CDPRODUTO;

         IF (V_SEQUENCIAL IS NOT NULL) THEN
            UPDATE ITEMPRODUTO
            SET VRUNITITEM    = VRUNITITEM   + V_VRTTTXAERO,
                VRTOTAITEM    = VRTOTAITEM   + V_VRTTTXAERO,
                VRCONTITEM    = VRCONTITEM   + V_VRTTTXAERO,
                VRBRUTITEM    = VRBRUTITEM   + V_VRTTTXAERO,
                VRITMOEDESTR  = VRITMOEDESTR + V_VRTTTXAEME
            WHERE CDFILIAL    = P_FILIAL     AND
                  NRLANCTONF  = V_NRLANCTONF AND
                  NRSEQITPROD = V_SEQUENCIAL;

         ELSE
            INSERT INTO ITEMPRODUTO (CDFILIAL, NRLANCTONF, NRSEQITPROD,
                                     CDPRODUTO, CDPRODEMIS,
                                     DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                     VRUNITITEM, VRDESCITEM,
                                     VRTOTAITEM,
                                     VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                     IDCONFORITEM, IDERROSITEM, IDAVISOSITEM)
            VALUES (P_FILIAL, V_NRLANCTONF, LPAD(TO_CHAR(V_NRSEQITPROD),4,'0'),
                    V_CDPRODUTO, '1'||V_CDPRODUTO,
                    V_NMPRODUTO, 'N', 1,
                    V_VRTTTXAERO, 0,
                    V_VRTTTXAERO,
                    V_VRTTTXAERO,
                    V_VRTTTXAERO,
                    V_VRTTTXAEME,
                    'N', '00000','00000');
         END IF;

         APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                     P_DTINIAPUR, P_DTFIMAPUR);
      ELSE
         APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                     P_DTINIAPUR, P_DTFIMAPUR);

         V_NRLANCTONFANT := V_NRLANCTONF;

         NOVO_CODIGO('LANCNF/FILIAL' || P_FILIPROC,V_NRLANCTONF);
         V_NRLANCTONF  := SUBSTR(V_NRLANCTONF, 11, 10);

         INSERT INTO NOTAFISCAL (CDFILIAL, NRLANCTONF, CDEMPRESA,
                                 CDINSCESTA, CDINSCMUNI, CDFILIEMIT,
                                 CDFILIRECE, IDTPIJURNF, NRINSJURNF,
                                 CDFORNECED, CDCLIENTE, IDERROS, IDAVISOS,
                                 IDBLOQUEADO, IDDOCFISCAL, IDDOCFINANC,
                                 NRNOTAFISC, DTENTRSAID,
                                 VRPRODUTOS, VRNOTAFISC, DTINIAPUFISC,
                                 DTAPROVACAO, CDOPERAPRO, DTCONTABIL,
                                 NRPLACAVEIC, SGUFVEIC, IDPGTOFRETE,
                                 DSQTDEVOLU, DSESPECVOLU, DSMARCAVOLU,
                                 DSNUMEVOLU, VRPBRUTOVOLU, VRPLIQUVOLU,
                                 IDENTRSAIDOP, CDTIPOOPER, CDSERIE, IDTPIJURTRAN,
                                 NRINSJURTRAN, VRTTMOEDESTR, IDSTATUS,
                                 IDSISTEMA, IDDOCFATUR, NRAPURACFAT, IDORIGDESTNF)
         VALUES (P_FILIPROC, V_NRLANCTONF, V_CDEMPRESA,
                 V_CDINSCESTA, V_CDINSCMUNI, P_FILIAL,
                 NULL, V_IDTPIJURCLIE, V_NRINSJURCLIE,
                 NULL, V_CDCLIENTE, NULL, NULL,
                 'N', 'N', 'N',
                 ' ', P_DTFECHAME,
                 0, 0, P_DTINIAPUR,
                 NULL, NULL, NULL,
                 NULL, NULL, NULL,
                 NULL, NULL, NULL,
                 NULL, 0, 0,
                 'S', '01', P_CDSERIE, P_IDTPIJURTRAN,
                 P_NRINSJURTRAN, 0, 'P', 'FAC', 'S', P_NRAPURACFAT, 'C');

         INSERT INTO ITEMPRODUTO (CDFILIAL, NRLANCTONF, NRSEQITPROD,
                                  CDPRODUTO, CDPRODEMIS,
                                  DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                                  VRUNITITEM, VRDESCITEM,
                                  VRTOTAITEM,
                                  VRCONTITEM, VRBRUTITEM, VRITMOEDESTR,
                                  IDCONFORITEM, IDERROSITEM, IDAVISOSITEM)
         VALUES (P_FILIPROC, V_NRLANCTONF, '0001',
                 V_CDPRODUTO, '1'||V_CDPRODUTO,
                 V_NMPRODUTO, 'N', 1,
                 V_VRTTTXAERO, 0,
                 V_VRTTTXAERO,
                 V_VRTTTXAERO,
                 V_VRTTTXAERO,
                 V_VRTTTXAEME,
                 'N', '00000','00000');

         APURAC_FECH(P_FILIAL, P_FILIPROC, V_NRLANCTONF, P_CDCIA, P_DTFECHAME,
                     P_DTINIAPUR, P_DTFIMAPUR);

         SELECT MAX(CDPRODEMIS)
         INTO V_CDSERVICO
         FROM ITEMPRODUTO
         WHERE CDFILIAL   = P_FILIAL AND
               NRLANCTONF = V_NRLANCTONFANT;

         UPDATE TRAB_APURAC
         SET NRLANCTONFAP = V_NRLANCTONF
         WHERE CDCIAAP       = P_CDCIA       AND
               CDFILIALAP    = P_FILIAL      AND
               NRAPURACFATAP = P_NRAPURACFAT AND
               CDSERVICOAP   = V_CDSERVICO   AND
               NRDELIVERYAP  = V_NRDELIVERY  AND
               NRLANCTONFAP  = V_NRLANCTONFANT;
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('APURAC_DELIVERY_SEPPRODSERV','5.45.xxx'); END;
/

